import { BaseURI, BigNumberString, ConsentFactoryContractError, ConsentName, EVMAccountAddress, EVMContractAddress, MarketplaceListing, MarketplaceTag, BlockchainCommonErrors, TransactionResponseError, DomainName } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { BaseContract } from "../implementations/BaseContract.js";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { IConsentFactoryContract } from "../interfaces/IConsentFactoryContract.js";
import { ContractOverrides, WrappedTransactionResponse } from "../interfaces/index.js";
export declare class ConsentFactoryContract extends BaseContract<ConsentFactoryContractError> implements IConsentFactoryContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    getContractAddress(): EVMContractAddress;
    createConsent(ownerAddress: EVMAccountAddress, baseUri: BaseURI, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    setListingDuration(listingDuration: number, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    setMaxTagsPerListing(maxTagsPerListing: number, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    registerStakingToken(stakingToken: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    adminRemoveListings(tag: MarketplaceTag, stakingToken: EVMContractAddress, removedSlot: BigNumberString[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    blockContentObject(stakingToken: EVMContractAddress, contentAddress: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    unblockContentObject(stakingToken: EVMContractAddress, contentAddress: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    estimateGasToCreateConsent(ownerAddress: EVMAccountAddress, baseUri: BaseURI, name: ConsentName): ResultAsync<bigint, ConsentFactoryContractError | BlockchainCommonErrors>;
    getDeployedConsents(): ResultAsync<EVMContractAddress[], ConsentFactoryContractError | BlockchainCommonErrors>;
    getListingsByTag(tag: MarketplaceTag, stakingToken: EVMContractAddress, removeExpired: boolean): ResultAsync<MarketplaceListing[], ConsentFactoryContractError | BlockchainCommonErrors>;
    getAddressOfConsentCreated(txRes: WrappedTransactionResponse): ResultAsync<EVMContractAddress, TransactionResponseError>;
    getGovernanceToken(): ResultAsync<EVMContractAddress, ConsentFactoryContractError | BlockchainCommonErrors>;
    isStakingToken(stakingToken: EVMContractAddress): ResultAsync<boolean, ConsentFactoryContractError | BlockchainCommonErrors>;
    listingDuration(): ResultAsync<number, ConsentFactoryContractError | BlockchainCommonErrors>;
    maxTagsPerListing(): ResultAsync<number, ConsentFactoryContractError | BlockchainCommonErrors>;
    getTagTotal(tag: MarketplaceTag, stakedToken: EVMContractAddress): ResultAsync<number, ConsentFactoryContractError | BlockchainCommonErrors>;
    getListingsForward(tag: MarketplaceTag, stakingToken: EVMContractAddress, startingSlot: BigNumberString, numberOfSlots: number, removeExpired: boolean): ResultAsync<MarketplaceListing[], ConsentFactoryContractError | BlockchainCommonErrors>;
    getListingsBackward(tag: MarketplaceTag, stakingToken: EVMContractAddress, startingSlot: BigNumberString, numberOfSlots: number, removeExpired: boolean): ResultAsync<MarketplaceListing[], ConsentFactoryContractError | BlockchainCommonErrors>;
    computeFee(slot: BigNumberString): ResultAsync<bigint, ConsentFactoryContractError | BlockchainCommonErrors>;
    removeExpiredListings(tag: MarketplaceTag, stakingToken: EVMContractAddress, slots: BigNumberString[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentFactoryContractError | BlockchainCommonErrors>;
    addDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    removeDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentFactoryContractError>;
    checkDomain(domain: DomainName): ResultAsync<boolean, ConsentFactoryContractError | BlockchainCommonErrors>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): ConsentFactoryContractError;
}
//# sourceMappingURL=ConsentFactoryContract.d.ts.map