import { EVMAccountAddress, EVMContractAddress, BlockchainCommonErrors, OFT20RewardContractError, Signature, BigNumberString } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { ERewardRoles } from "../interfaces/enums/index.js";
import { ContractOverrides, IOFT20RewardContract, WrappedTransactionResponse } from "../interfaces/index.js";
export declare class OFT20RewardContract extends ERC7529Contract<OFT20RewardContractError> implements IOFT20RewardContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    name(): ResultAsync<string, OFT20RewardContractError | BlockchainCommonErrors>;
    symbol(): ResultAsync<string, OFT20RewardContractError | BlockchainCommonErrors>;
    decimals(): ResultAsync<number, OFT20RewardContractError | BlockchainCommonErrors>;
    totalSupply(): ResultAsync<bigint, OFT20RewardContractError | BlockchainCommonErrors>;
    balanceOf(address: EVMAccountAddress | EVMContractAddress): ResultAsync<bigint, OFT20RewardContractError | BlockchainCommonErrors>;
    allowance(owner: EVMAccountAddress | EVMContractAddress, spender: EVMAccountAddress | EVMContractAddress): ResultAsync<bigint, OFT20RewardContractError | BlockchainCommonErrors>;
    approve(spender: EVMAccountAddress | EVMContractAddress, amount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    transfer(recipient: EVMAccountAddress | EVMContractAddress, amount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    transferFrom(sender: EVMAccountAddress | EVMContractAddress, recipient: EVMAccountAddress | EVMContractAddress, amount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    hasRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress): ResultAsync<boolean, OFT20RewardContractError | BlockchainCommonErrors>;
    grantRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    revokeRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    renounceRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    redeem(account: EVMAccountAddress, amount: BigNumberString, signature: Signature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | OFT20RewardContractError>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): OFT20RewardContractError;
    filters: {
        Transfer: (fromAddress: EVMAccountAddress | null, toAddress: EVMAccountAddress | null) => ethers.DeferredTopicFilter;
    };
}
//# sourceMappingURL=OFT20RewardContract.d.ts.map