import { EVMContractAddress, BigNumberString, BlockchainCommonErrors, MarketplaceTag, MarketplaceListing } from "@snickerdoodlelabs/objects";
import { ResultAsync } from "neverthrow";
import { IBaseContract } from "../interfaces/IBaseContract.js";
import { ContractOverrides, WrappedTransactionResponse } from "../interfaces/objects";
export interface IContentFactoryContract<T> extends IBaseContract {
    getGovernanceToken(): ResultAsync<EVMContractAddress, T | BlockchainCommonErrors>;
    isStakingToken(stakingToken: EVMContractAddress): ResultAsync<boolean, T | BlockchainCommonErrors>;
    listingDuration(): ResultAsync<number, T | BlockchainCommonErrors>;
    maxTagsPerListing(): ResultAsync<number, T | BlockchainCommonErrors>;
    getTagTotal(tag: MarketplaceTag, stakedToken: EVMContractAddress): ResultAsync<number, T | BlockchainCommonErrors>;
    getListingsForward(tag: MarketplaceTag, stakingToken: EVMContractAddress, startingSlot: BigNumberString, numberOfSlots: number, removeExpired: boolean): ResultAsync<MarketplaceListing[], T | BlockchainCommonErrors>;
    getListingsBackward(tag: MarketplaceTag, stakingToken: EVMContractAddress, startingSlot: BigNumberString, numberOfSlots: number, removeExpired: boolean): ResultAsync<MarketplaceListing[], T | BlockchainCommonErrors>;
    computeFee(slot: BigNumberString): ResultAsync<bigint, T | BlockchainCommonErrors>;
    removeExpiredListings(tag: MarketplaceTag, stakingToken: EVMContractAddress, slots: BigNumberString[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, T | BlockchainCommonErrors>;
}
export interface IInternalContentFactoryContract<T> extends IBaseContract {
    initializeTag(tag: MarketplaceTag, stakingToken: EVMContractAddress, newHead: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | T>;
    insertUpstream(tag: MarketplaceTag, stakingToken: EVMContractAddress, newSlot: BigNumberString, existingSlot: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | T>;
    moveUpstream(tag: MarketplaceTag, stakingToken: EVMContractAddress, newSlot: BigNumberString, downstreamSlot: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | T>;
    insertDownstream(tag: MarketplaceTag, stakingToken: EVMContractAddress, existingSlot: BigNumberString, newSlot: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | T>;
    replaceExpiredListing(tag: MarketplaceTag, stakingToken: EVMContractAddress, slot: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | T>;
    removeListing(tag: MarketplaceTag, stakingToken: EVMContractAddress, removedSlot: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | T>;
}
export declare const IContentFactoryContractType: unique symbol;
//# sourceMappingURL=IContentFactoryContract.d.ts.map